@@ -177,8 +177,8 @@ def fetal_fraction_XY(
         context=dict(
             sex_thresholds={
                 "XY_fetal_fraction_y": sex_thresholds.XY_fetal_fraction_y(),
-                # "XX_lower": sex_thresholds.XX_lower(),
-                # "XX_upper": sex_thresholds.XX_upper(),
+                "XX_lower": sex_thresholds.XX_lower(),
+                "XX_upper": sex_thresholds.XX_upper(),
                 # "XY_lower": sex_thresholds.XY_lower(),
                 # "XY_upper": sex_thresholds.XY_upper(),
                 # "XXY": sex_thresholds.XXY(),
